@@ -44,7 +44,8 @@ def remove_all(str_list, element, ignore_cases=False):
     optionally letter cases"""
 
     if ignore_cases:
-        new_list = [e for e in str_list if e.lower() != element.lower()]
+        new_list = [e for e in str_list \
+                    if str(e).lower() != str(element).lower()]
     else:
         new_list = [e for e in str_list if e != element]
 
